@@ -5,7 +5,7 @@
 #
 # Copyright YMIRLINK, Inc.
 # -----------------------------------------------------------------------------
-# $Id: make_ini.pm,v 1.3 2006/12/04 09:35:21 hio Exp $
+# $Id: make_ini.pm,v 1.1 2006/11/06 11:21:49 hio Exp $
 # -----------------------------------------------------------------------------
 package t::make_ini;
 use strict;
@@ -22,7 +22,6 @@ our $NOCLEAN = $ENV{TL_TEST_NOCLEAN};
 
 # -----------------------------------------------------------------------------
 # $pkg->import({ ini => \%ini, });
-# $pkg->import({ ini => sub{\%ini}, cleanup=>[qw(..)]);
 # use t::make_ini \%opts;
 # -----------------------------------------------------------------------------
 sub import
@@ -35,10 +34,7 @@ sub import
 	ref($ini) eq 'CODE' and $ini = $ini->();
 	write_ini($ini);
 	
-	if( $opts->{clean} )
-	{
-		push(@cleanup, @{$opts->{clean}});
-	}
+	push(@cleanup, @{$opts->{clean}});
 }
 
 # -----------------------------------------------------------------------------
@@ -62,8 +58,7 @@ END
 }
 
 # -----------------------------------------------------------------------------
-# write_ini(%ini);
-# write ini on $t::make_ini::INI_FILE;
+# write ini.
 # -----------------------------------------------------------------------------
 sub write_ini
 {
@@ -71,12 +66,8 @@ sub write_ini
 	
 	#print STDERR "write [$INI_FILE]\n";
 	open my $fh, '>', $INI_FILE or die "could not create file [$INI_FILE]: $!";
-	my @keys = sort keys %$hash;
-	@keys = ((grep{/^TL$/}@keys),(grep{!/^TL$/}@keys));
-	my $cont = 0;
-	foreach my $group (@keys)
+	foreach my $group (sort keys %$hash)
 	{
-		$cont and print $fh "\n";
 		print $fh "[$group]\n";
 		foreach my $key (sort keys %{$hash->{$group}})
 		{
@@ -84,7 +75,6 @@ sub write_ini
 			ref($val) eq 'ARRAY' and $val = join(',',@$val);
 			print $fh "$key = $val\n";
 		}
-		$cont = 1;
 	}
 	close $fh;
 	push(@cleanup, $INI_FILE);
